@@ -1,11 +1,11 @@
 
-if (exists("vcov") & !exists("vcov.coxph")){                            
-    vcov.coxph<-function (object, ...) {
-        rval<-object$var
-        dimnames(rval)<-list(names(coef(object)),names(coef(object)))
-        rval
-    }
-    vcov.survreg<-function (object, ...) 
+vcov.coxph<-function (object, ...) {
+    rval<-object$var
+    dimnames(rval)<-list(names(coef(object)),names(coef(object)))
+    rval
+}
+
+vcov.survreg<-function (object, ...) {
         object$var
 }
 
