@@ -165,7 +165,8 @@ void cox_callback (int which, double *coef, double *first,
                    double *second, double *penalty, int *flag, int p, void *fexpr, void *rho);
 
 void pyears1(int   *sn,      int   *sny,      int   *sdoevent, 
-	     double *sy,      int   *sedim,    int   *efac, 
+	     double *sy,      double *weight,       
+             int   *sedim,   int   *efac, 
 	     int   *edims,   double *secut,    double *expect, 
 	     double *sedata,  int   *sodim,    int   *ofac, 
 	     int   *odims,   double *socut,    int   *smethod, 
@@ -173,7 +174,7 @@ void pyears1(int   *sn,      int   *sny,      int   *sdoevent,
 	     double *pcount,  double *pexpect,  double *offtable);
 
 void pyears2(int   *sn,      int   *sny,   int   *sdoevent, 
-	     double *sy,      int   *sodim, int   *ofac, 
+	     double *sy,      double *wt,    int   *sodim,    int   *ofac, 
 	     int   *odims,   double *socut, double *sodata,
 	     double *pyears,  double *pn,    double *pcount, 
 	     double *offtable);
@@ -184,6 +185,7 @@ void pyears3(int   *sdeath,    int   *sn,    int   *sedim,
 	     int   *sntime,    int   *sngrp, double *times,
 	     double *esurv,     int   *nsurv);
 
+
 double pystep(int nc,        int  *index,  int  *index2,   double *wt, 
 	      double *data,  int *fac,    int *dims,     double **cuts, 
 	      double step,   int  edge);
@@ -217,9 +219,9 @@ void survfit2(int   *sn,      double *y,       double *wt,
 /* 		double *std_err,    double *upper,      double *lower, */
 /* 		double *new_start,  int   *num_extend, int   *times_strata, */
 /* 		double *temp_times); */
-void survindex2(long   *n,     double *stime,   long   *strata, 
-		long   *ntime, double *time,    long   *nstrat, 
-		long   *indx,  long   *indx2);
+void survindex2(int   *n,     double *stime,   int   *strata, 
+		int   *ntime, double *time,    int   *nstrat, 
+		int   *indx,  int   *indx2);
  
 void survreg2(int   *maxiter,   int   *nx,    int   *nvarx, 
 	     double *y,          int   *ny,    double *covar2, double *wtx,
